@@ -1,6 +1,6 @@
-/* $Id: xfce-fileutils.c 17217 2005-08-31 10:19:12Z benny $ */
+/* $Id: xfce-fileutils.c 21068 2006-04-18 21:35:22Z benny $ */
 /*-
- * Copyright (c) 2003-2005 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -37,7 +37,9 @@
 #include <unistd.h>
 #endif
 
-#include <libxfce4util/libxfce4util.h>
+#include <libxfce4util/libxfce4util-private.h>
+#include <libxfce4util/libxfce4util-alias.h>
+
 
 
 /**
@@ -59,9 +61,9 @@
  * Since: 4.2
  **/
 gboolean
-xfce_mkdirhier (const gchar  *whole_path,
-                unsigned long omode,
-                GError      **error)
+xfce_mkdirhier (const gchar *whole_path,
+                gulong       omode,
+                GError     **error)
 {
   /* Stolen from FreeBSD's mkdir(1) with modifications to make it
    * work properly with NFS on Solaris */
@@ -144,6 +146,9 @@ xfce_mkdirhier (const gchar  *whole_path,
 
   if (!retval && error != NULL)
     {
+      /* be sure to initialize the i18n support */
+      _xfce_i18n_init ();
+
       g_set_error (error, G_FILE_ERROR,
                    g_file_error_from_errno (errno),
                    _("Error creating directory '%s': %s"),
@@ -153,3 +158,7 @@ xfce_mkdirhier (const gchar  *whole_path,
   return retval;
 }
 
+
+
+#define __XFCE_FILEUTILS_C__
+#include <libxfce4util/libxfce4util-aliasdef.c>
